/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.commons;

/**
 * Single place for retrieval of proxy settings.
 * Gets proxy settings from system properties.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: URLBuilder.java 1357 2011-05-08 04:24:47Z yegor256@yahoo.com $
 */
public class ProxyConfig {

    /**
     * System property key name for http proxy.
     */
    private static final String HOST_KEY = "http.proxyHost";

    /**
     * System property key name for http port.
     */
    private static final String PORT_KEY = "http.proxyPort";

    /**
     * Default proxy port to use when it doesn't exist in system properties.
     */
    private static final Integer DEFAULT_PORT = 80;

    /**
     * Get proxy host from system properties.
     * @return proxy host
     */
    public final String getHost() {
        return System.getProperty(this.HOST_KEY);
    }

    /**
     * Get proxy port number from system properties.
     * @return proxy port number
     */
    public final int getPort() {
        int proxyPort;
        try {
            proxyPort = Integer.parseInt(System.getProperty(this.PORT_KEY,
                this.DEFAULT_PORT.toString()));
        } catch (NumberFormatException numberException) {
            proxyPort = this.DEFAULT_PORT;
        }
        return proxyPort;
    }

}
